@@ -5,7 +5,7 @@
 ;; Author: Yoshiki Kurihara <kurihara@cpan.org>
 ;;         Marshall T. Vandegrift <llasram@gmail.com>
 ;; Keywords: data yaml
-;; Version: 0.0.4
+;; Version: 0.0.6
 
 ;; This file is not part of Emacs
 
@@ -104,10 +104,16 @@ that key is pressed to begin a block literal."
   :group 'faces
   :group 'yaml)
 
+(defcustom yaml-imenu-generic-expression
+  '((nil  "^\\(:?[a-zA-Z_-]+\\):"          1))
+  "The imenu regex to parse an outline of the yaml file."
+  :type 'string
+  :group 'yaml)
+
 
 ;; Constants
 
-(defconst yaml-mode-version "0.0.4" "Version of `yaml-mode.'")
+(defconst yaml-mode-version "0.0.6" "Version of `yaml-mode.'")
 
 (defconst yaml-blank-line-re "^ *$"
   "Regexp matching a line containing only (valid) whitespace.")
@@ -199,7 +205,7 @@ that key is pressed to begin a block literal."
   (modify-syntax-entry ?# "<" yaml-mode-syntax-table)
   (modify-syntax-entry ?\n ">" yaml-mode-syntax-table)
   (modify-syntax-entry ?\\ "\\" yaml-mode-syntax-table)
-  (modify-syntax-entry ?- "." yaml-mode-syntax-table)
+  (modify-syntax-entry ?- "w" yaml-mode-syntax-table)
   (modify-syntax-entry ?_ "_" yaml-mode-syntax-table)
   (modify-syntax-entry ?\( "." yaml-mode-syntax-table)
   (modify-syntax-entry ?\) "." yaml-mode-syntax-table)
@@ -381,6 +387,16 @@ margin."
     (if (and (not arg) (looking-at yaml-document-delimiter-re))
         (delete-horizontal-space))))
 
+
+(defun yaml-set-imenu-generic-expression ()
+  (make-local-variable 'imenu-generic-expression)
+  (make-local-variable 'imenu-create-index-function)
+  (setq imenu-create-index-function 'imenu-default-create-index-function)
+  (setq imenu-generic-expression yaml-imenu-generic-expression))
+
+(add-hook 'yaml-mode-hook 'yaml-set-imenu-generic-expression)
+
+
 (defun yaml-mode-version ()
   "Diplay version of `yaml-mode'."
   (interactive)
